@@ -934,22 +934,50 @@ class UnifiedDashboard:
         request_counter.labels(model=model, status=status, backend=backend).inc()
         request_duration.labels(model=model, backend=backend).observe(latency_ms / 1000)
 
-    def run(self, host: str = "0.0.0.0", debug: bool = False):
-        """Run dashboard server (production-ready with Waitress)."""
+    def run(self, host: str = "0.0.0.0", debug: bool = False, allow_fallback: bool = True):
+        """
+        Run dashboard server (production-ready with Waitress).
+
+        Args:
+            host: Host to bind to
+            debug: Enable debug mode
+            allow_fallback: If True and port is in use, assume another dashboard is running
+        """
+        # Check if dashboard is already running on this port
+        if allow_fallback:
+            import socket
+            sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+            result = sock.connect_ex(('localhost', self.dashboard_port))
+            sock.close()
+
+            if result == 0:
+                # Port is in use - another dashboard is likely running
+                logger.info(f"📊 Dashboard already running on port {self.dashboard_port}")
+                logger.info(f"   Connecting to existing dashboard at http://localhost:{self.dashboard_port}")
+                logger.info("✅ Application will use shared dashboard for observability")
+                return  # Don't start a new server
+
         logger.info(f"🚀 Starting Unified Dashboard on http://{host}:{self.dashboard_port}")
         logger.info(f"   Ray Dashboard: http://localhost:{self.ray_dashboard_port}")
         logger.info(f"   Dask Dashboard: http://localhost:{self.dask_dashboard_port}")
         logger.info(f"   Prometheus: http://{host}:{self.dashboard_port}/api/prometheus")
 
-        if debug:
-            # Development mode - use Flask's dev server
-            logger.warning("⚠️  Running in DEBUG mode - not for production!")
-            self.app.run(host=host, port=self.dashboard_port, debug=True)
-        else:
-            # Production mode - use Waitress
-            from waitress import serve
-            logger.info("✅ Using Waitress production server")
-            serve(self.app, host=host, port=self.dashboard_port, threads=4)
+        try:
+            if debug:
+                # Development mode - use Flask's dev server
+                logger.warning("⚠️  Running in DEBUG mode - not for production!")
+                self.app.run(host=host, port=self.dashboard_port, debug=True)
+            else:
+                # Production mode - use Waitress
+                from waitress import serve
+                logger.info("✅ Using Waitress production server")
+                serve(self.app, host=host, port=self.dashboard_port, threads=4)
+        except OSError as e:
+            if "Address already in use" in str(e):
+                logger.warning(f"⚠️  Port {self.dashboard_port} already in use")
+                logger.info("✅ Assuming another SOLLOL dashboard is running - using shared instance")
+            else:
+                raise
 
 
 # Unified Dashboard HTML Template
